:desc: Get started with machine learning dialogue management to scale your bot
       development using Rasa as a conversational AI platform.

.. _about-rasa-core:

The Rasa Core Dialogue Engine
=============================

.. chat-bubble::
   :text: What am I looking at?
   :sender: bot


.. chat-bubble::
   :text: Rasa Core is a dialogue engine for building AI assistants.
   :sender: user

.. chat-bubble::
   :text: It's part of the open source Rasa framework.
   :sender: user

.. chat-bubble::
   :text: What's cool about it?
   :sender: bot

.. chat-bubble::
   :text: Rather than a bunch of if/else statements, it uses a machine learning model trained on example conversations to decide what to do next.
   :sender: user

.. chat-bubble::
   :text: That sounds harder than writing a few if statements.
   :sender: bot


.. chat-bubble::
   :text: In the beginning of a project, it seems easier to just hard-code some logic.
   :sender: user

.. chat-bubble::
   :text: Rasa helps you when you want to go past that and create a bot that can handle more complexity.
      This <a href="https://medium.com/rasa-blog/a-new-approach-to-conversational-software-2e64a5d05f2a" target="_blank">blog post</a> explains the philosophy behind Rasa Core.
   :sender: user


.. chat-bubble::
   :text: Can I see it in action?
   :sender: bot

.. chat-bubble::
   :text: We thought you'd never ask!
   :sender: user

.. chat-bubble::
   :text: Head over to the <a href="../../user-guide/rasa-tutorial">Rasa Tutorial</a> for an interactive example.
   :sender: user
